-------
Contact
-------

In order to discuss :term:`FiPy` with other users and with the developers,
we encourage you to use one of the following modes of communication.  We
monitor all of these, so there is no need to post to more than one of them.

You may want to read the following resource about asking
effective questions:  http://www.catb.org/~esr/faqs/smart-questions.html

If you are having trouble, we are able to offer much more effective help if
you provide a `minimal reproducible example
<https://stackoverflow.com/help/minimal-reproducible-example>`__.

GitHub Discussions
==================

https://github.com/usnistgov/fipy/discussions

Suitable for open-ended conversations, troubleshooting, showing off…

If a discussion highlights a bug or feature request, it’s easy for us to
migrate `GitHub Discussions`_ to `GitHub Issues`_.

GitHub Issues
=============

https://github.com/usnistgov/fipy/issues

Suitable for bug reports, feature requests, and patch submissions.

StackOverflow
=============

https://stackoverflow.com/questions/tagged/fipy

Suitable for questions that (probably) have definitive answers ("How do
I...?").  It doesn’t work so well for back-and-forth conversations, which
are better suited to `GitHub Discussions`_. Further, it's
`bad at math <https://meta.stackexchange.com/questions/30559/latex-on-stack-overflow>`_
and they tend to delete answers that link to our existing
documentation, meaning that we'd need to expend considerable effort, using
an inferior tool, to duplicate things we've already written.

Seriously, use `GitHub Discussions`_.

Mailing List
============

.. attention::

   The mailing list is deprecated. Please use `GitHub Discussions`_, instead.

You can sign up for the mailing list by sending a `subscription
email <mailto:fipy+subscribe@list.nist.gov>`__ to
<mailto:fipy+subscribe@list.nist.gov>.

Once you are subscribed, you can post messages to the list simply by
addressing email to <mailto:fipy@list.nist.gov>.

To get off the list, send a message to
<mailto:fipy+unsubscribe@list.nist.gov>.

Send a message to <mailto:fipy+help@list.nist.gov> to learn other mailing
list configurations you can change.

The list is hosted as a Google group.  If you are subscribed with a Google
account, you can interact with the list, configure your subscription, and
see the archives at https://list.nist.gov/fipy.

List Archive
------------

https://www.mail-archive.com/fipy@list.nist.gov/

Copies of messages sent to fipy@list.nist.gov are stored at `The Mail Archive`_.

Older messages are archived at https://www.mail-archive.com/fipy@nist.gov/.

(note: we have also historically sent copies to
http://dir.gmane.org/gmane.comp.python.fipy, but the GMANE_ site now
appears to be defunct_.)


.. _The Mail Archive:   https://www.mail-archive.com

.. _GMANE:    http://gmane.org/

.. _defunct: https://lars.ingebrigtsen.no/2016/07/28/the-end-of-gmane/
